@@ -37,12 +37,12 @@ class CrModel:
         #crossroad edges creation
         crossroad_edges = {}
         for edge in seg_crossroad.edges_by_nodes:
-            edge_id = "%s%s"%(edge[0],edge[1])
-            crossroad_edges[edge_id] = createWay(edge, G)
+            edge_id = "%s;%s"%(edge[0],edge[1])
+            crossroad_edges[edge_id] = createWay(edge_id, edge, G)
         for branch in seg_crossroad.branches:
             for edge in branch.edges_by_nodes:
-                edge_id = "%s%s"%(edge[0],edge[1])
-                crossroad_edges[edge_id] = createWay(edge, G, seg_crossroad.border_nodes)    
+                edge_id = "%s;%s"%(edge[0],edge[1])
+                crossroad_edges[edge_id] = createWay(edge_id, edge, G, seg_crossroad.border_nodes)    
 
         # Get border path of the intersection, then keep only the border nodes (the external nodes of the branches)
         border_path = getBorderPath(G, crossroad_inner_nodes, crossroad_border_nodes, crossroad_external_nodes, crossroad_edges)
@@ -101,13 +101,13 @@ class CrModel:
                     n1 = sidewalk_path[j]
                     n2 = sidewalk_path[j+1]
                     way = None
-                    ids = ["%s%s"%(n1,n2), "%s%s"%(n2,n1)]
+                    ids = ["%s;%s"%(n1,n2), "%s;%s"%(n2,n1)]
                     for id in ids:
                         if id in crossroad_edges:
                             way = crossroad_edges[id]
                     # if the way does not exist we create it (may not happen but sometimes it is)
                     if not way:
-                        way = createWay([n1,n2], G)
+                        way = createWay("%s;%s"%(n1, n2), [n1,n2], G)
                         crossroad_edges[id] = way
                     # if the sidewalk goes in the same direction as the way, it's the left sidewalk. Otherwise it's the right one.
                     if way.junctions[0].id == n1:
@@ -135,7 +135,7 @@ class CrModel:
                     n1 = island_path[j]
                     n2 = island_path[j+1]
                     way = None
-                    ids = ["%s%s"%(n1,n2), "%s%s"%(n2,n1)]
+                    ids = ["%s;%s"%(n1,n2), "%s;%s"%(n2,n1)]
                     for id in ids:
                         if id in crossroad_edges:
                             way = crossroad_edges[id]
@@ -217,7 +217,7 @@ class CrModel:
         #
 
         self.crossroad = Intersection(None, branches, crossroad_center)
-        self.crossroad.junctions = {**crossroad_inner_nodes, **crossroad_border_nodes}
+        self.crossroad.junctions = {**crossroad_inner_nodes, **crossroad_border_nodes, **crossroad_external_nodes}
         self.crossroad.ways = crossroad_edges
         self.crossroad.crossings = crossings
 
@@ -243,7 +243,7 @@ class CrModel:
             way = self.crossroad.ways[way_id]
             way_data = {
                 "name" : way.name,
-                "junctions" : [junction.id for junction in way.junctions],
+                "junctions" : [str(junction.id) for junction in way.junctions],
                 "channels" : None,
                 "sidewalks" : None,
                 "islands" : None
@@ -262,7 +262,7 @@ class CrModel:
             sidewalks_ids = []
             for sidewalk in way.sidewalks:
                 if sidewalk:
-                    sidewalks_ids.append(sidewalk.id)
+                    sidewalks_ids.append(str(sidewalk.id))
                     data["pedestrian_nodes"][sidewalk.id] = { "type" : "Sidewalk" }
                 else:
                     sidewalks_ids.append(None)
@@ -272,7 +272,7 @@ class CrModel:
             islands_ids = []
             for island in way.islands:
                 if island:
-                    islands_ids.append(island.id)
+                    islands_ids.append(str(island.id))
                     data["pedestrian_nodes"][island.id] = { "type" : "Island" }
                 else:
                     islands_ids.append(None)
@@ -299,7 +299,7 @@ class CrModel:
                 # Pedestrian nodes handling
                 junction_data["pedestrian_nodes"] = []
                 for pedestrian_node in junction.pedestrian_nodes:
-                    junction_data["pedestrian_nodes"].append(pedestrian_node.id)
+                    junction_data["pedestrian_nodes"].append(str(pedestrian_node.id))
                     data["pedestrian_nodes"][pedestrian_node.id] = { "type" : pedestrian_node.__class__.__name__ }
 
             # Attributes : ptl_sound
@@ -324,7 +324,7 @@ class CrModel:
                 "street_name" : branch.street_name, 
                 "ways" : [way.id for way in branch.ways],
                 "crossing" : {
-                    "crosswalks" : [crosswalk.id for crosswalk in branch.crossing.crosswalks]
+                    "crosswalks" : [str(crosswalk.id) for crosswalk in branch.crossing.crosswalks]
                 }
             }
 
